{% extends "layout/default.html" %}
{% block body %} 
  <br>
<a href="{{ url_for('core.RERA') }}"><img width="200px" height="200" src="{{ url_for('static', filename='images/ratp/RERA.jpg') }}"></a>
<a href="{{ url_for('core.RERB') }}"><img width="200px" height="200" src="{{ url_for('static', filename='images/ratp/RERB.jpg') }}"></a>

{% endblock %}