.main
{
  text-align: center;
  font-family: 'Montserrat', sans-serif;

}

body
{
	background-color: #EEEEEE;
}


/* Tooltip container */
.tooltip {
    position: relative;
    display: inline-block;
   
}

/* Tooltip text */
.tooltip .tooltiptext {
    visibility: hidden;
    width: 120px;
    background-color: black;
    color: #fff;
    text-align: center;
    padding: 5px 0;
    border-radius: 6px;
 
    /* Position the tooltip text - see examples below! */
    position: absolute;
    z-index: 1;
    width: 120px;
    bottom: 100%;
    left: 50%;
    margin-left: -60px;
}

/* Show the tooltip text when you mouse over the tooltip container */
.tooltip:hover .tooltiptext {
    visibility: visible;
}
 

a , a:visited {

    color:#90b8de;
    text-decoration:underline;

}

a:hover{
    text-decoration:none;
}