{% extends "layout/login.html" %}
{% block body %}




 <div class="login-page">
  <form class="register-form" method=post action=""> 
  <div class="form">  
 
     <input type="text" id="username" name="username" 
            placeholder="{{_('Name')}}" value="{{ request.form.username }}"
            required>

      <input type="password" id="password" name="password" 
            placeholder="{{_('Password')}}" value="{{ request.form.password }}"
            required>

      <input type="password" id="verifpassword" name="verifpassword" 
            placeholder="{{_('Confirm password')}}" value="{{ request.form.verifpassword }}"
            required>

      <input type="email" id="email" name="email" class="input-xlarge"
            placeholder="{{_('Email')}}" value="{{ request.form.email }}"
            required>

      <button>{{_("Register")}}</button>
      <p class="message">{{_("Already registered ?")}} <a href="{{ url_for('core.login') }}">{{_("Login")}}</a></p>
    </form>
  </div>
</div>
{% endblock %}