{% extends "layout/login.html" %}
{% block body %}

 <div class="login-page" style="color=white;">

<h1>{{_("Welcome !")}}</h1>
<br>
<p>{{("Please go to you mail ( see in the spam ) and confirm your account")}}</p>
<p>{{_("No send ?")}} <a href="{{ url_for('core.resend_confirmation') }}">{{_("Re Send")}}</a>.</p>

</div>


{% endblock %}