.loader{
    background: url('/static/images/loader.gif') 50% 50% no-repeat rgba(255, 255, 255, 0.8);
    cursor: wait;
    height: 100%;
    left: 0;
    position: fixed;
    top: 0;
    width: 100%;
    z-index: 9999;
}
    .loader h1{
        background: none;
        border: none;
        color: #458976;
        font-size: 22px;
        font-family: "Open Sans",sans-serif;
        font-variant: small-caps;
        font-weight: 700;
        height: 700px;
        line-height: 700px;
        margin: 0 0 10px;
        padding: 0;
        text-align: center;
    }