{% extends "layout/install.html" %}
{% block body %}

<header>
 	<center><h1>Installation d'Onyx</h1></center> 
</header>   



<nav>
	<center>
    <div class="nav-wrapper blue darken-1">
      <div class="col s12">
        <span class="breadcrumb">Finition</span>
      </div>
    </div>
    </center>
</nav>
            
  

    <div class="row" id="step1">
        <div class="col-md-8 col-md-offset-2">
          <div class="well well-sm">
            <div class="card-panel blue-grey grey lighten-3">
              <h3>Installation Terminée</h3>
              <p>Veuillez redemarrer Onyx pour prendre en compte tous vos paramètre !</p>
            
            </div>

          </div>
        </div>
    </div>

   

</div>




      <footer>
        <p>© Onyx 2016 - Si vous rencontrez quelconques problème rendez-vous sur notre forum : <a href="http://onyxlabs.fr/forum/">http://onyxlabs.fr/forum/</a></p>
      </footer>
      
{% endblock %}
