{% extends "layout/default.html" %}
{% block body %}

	<h3>{{_("If you need help you can go to ")}} <a href="https://blog.onyxlabs.fr">Onyxlabs</a></h3>
	<h3>{{_("Or in the forum ")}} <a href="https://blog.onyxlabs.fr/forum">Forum</a> !</h3>

{% endblock %}

