{% extends "layout/default.html" %}
{% block body %}

	<br>
	<a href="{{ url_for('core.metro') }}" class="waves-effect waves-light btn {{ buttonColor }}">Metro</a>
	<a  href="{{ url_for('core.rer') }}" class="waves-effect waves-light btn {{ buttonColor }}">RER</a>

{% endblock %}