{% extends "layout/default.html" %}
{% block body %} 
	<br>

				<form method="post"
  			action=""
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
     		 <label for="metroServiceStationForm_station">Nom de la station : </label> <select name="metrostation" class="browser-default" id="metroServiceStationForm_station">
     		 <option value="--Choisissez votre station--">--Choisissez votre station--</option>
     		 <option value="gambetta">Gambetta</option>
			<option value="pelleport">Pelleport</option>
			<option value="porte+des+lilas">Porte des Lilas</option>
			<option value="saint+fargeau">Saint-Fargeau</option>
			</form>
			</select>
			<form method="post"
  			action="result"
  			id="metro-service-arret-form">
   			 <div id="horMetroStations" class="stationField">
    		  <label for="metroServiceStationForm_station">Direction : </label> <select name="metrodirection" class="browser-default" id="metroServiceStationForm_station">
				<option value="--Choisissez votre station--">--Choisissez votre direction--</option>
				<option value="A">Gambetta</option>
				<option value="R">Porte des Lilas</option></form></select></br>

    <button class="btn {{ buttonColor }}" type="submit"><span class="glyphicon glyphicon-ok-sign"></span>Envoyer</button>




{% endblock %}
