{% extends "layout/default.html" %}
{% block body %}
		
  <div class="card-panel grey lighten-3">

  {% if currentAdmin == 1 %}
		<h2>{{_("Accounts")}}</h2>		 
		        <h4>{{ error }}</h4>
			<table  class="table table-striped">	
				 <tbody id="table_alarmes">
				<tr>
					<th>{{_("Name")}}</th>
					<th>{{_("Email")}}</th>
					<th>{{_("Id")}}</th>
					<th>{{_("Delete")}}</th>
				</tr>
				<tr>
		
					<td>{% for tab in username %}
							{{ tab }}</br>
						{% endfor %}
					</td>
					<td>{% for tab in email %}
							{{ tab }}</br>
						{% endfor %}
					</td>
					<td>{% for tab in id %}
							{{ tab }}</br>
						{% endfor %}
					</td>	
					<td>
					{% for tab in id %}
					<a href="{{ url_for('core.delete_account' , id_delete=tab) }}"><i class="fa fa-times" aria-hidden="true"></i></a></br>
					{% endfor %}
					</td>		
				</tr>
			</tbody>
			</table>

  {% else %}

  	<h3>{{_("You're not an administrator so we can't delete accounts")}}</h3>
  {% endif %}
		        
		        
		 </div>

		 
{% endblock %}