{% extends "layout/default.html" %}
{% block body %}

	<h1>{{ _("Welcome to Onyx") }}</h1>
	<h3>{{ _("For access to our blog and download Onyx :") }} <a href="https://blog.onyxlabs.fr">blog.onyxlabs.fr</a></h3>

{% endblock %}


   