{% extends "layout/default.html" %}
{% block body %}

	<h1>{{_("Options")}}</h1>

  <a href="{{ url_for('api.doc') }}" class="btn {{ buttonColor }}">{{ _("Go To the API") }}</a>
  <br><br>

	<form class="form" method=post action="">
	  <div class="container">
      <label for="lang" >{{_("Langue")}}</label>
      <select name="lang" class="browser-default">
      <option value="fr">{{_("French")}}</option>
      <option value="en">{{_("English")}}</option> 
      </select>
      </div>
      <br><br>
      <button class="btn {{ buttonColor }}">{{_("Save")}}</button>
    </form>


	{% if currentAdmin == 1 %}
		<a href="{{ url_for('core.maj') }}" class="btn {{ buttonColor }}">{{_("Update Onyx")}}</a><br><br>
		<a href="{{ url_for('core.accountdel') }}" class="btn {{ buttonColor }}">{{_("Remove account")}}</a>
	{% endif %}


{% endblock %}
{% block script %}


{% endblock %}
