{% extends "layout/login.html" %}
{% block body %}


  <div class="login-page">
  <form class="register-form" method=post action=""> 
  <div class="form">
      <input type="text" id="email" name="email" 
            placeholder="{{_('Email')}}" required>
      <input type="password" id="password" name="password" class="input-xlarge"
            placeholder="{{_('Password')}}" required>
      <button>{{_("Login")}}</button>
      <p class="message">{{_("Forget your password")}} ? <a href="{{ url_for('core.resetpassword') }}">{{_("Reset password")}}</a></p>
      <p class="message">{{_("Not register ?")}} <a href="{{ url_for('core.register') }}">{{_("Register")}}</a></p>
    </form>
  </div>
</div>


{% endblock %}