<h2>{{_("Change your password")}}</h2><br>
<p>{{_("Hello ! If you ask a new password click in this link if not ignore it")}}</p>
<p><a href="{{ confirm_url }}">{{ confirm_url }}</a></p>
<br>
<p>Onyx Software</p>
