{% extends "layout/default.html" %}
{% block body %} 


<br>
<a href="{{ url_for('core.M1') }}"><img src="{{ url_for('static', filename='images/ratp/M1.png') }}"></a>
<a href="{{ url_for('core.M2') }}"><img src="{{ url_for('static', filename='images/ratp/M2.png') }}"></a>
<a href="{{ url_for('core.M3') }}"><img src="{{ url_for('static', filename='images/ratp/M3.png') }}"></a>
<a href="{{ url_for('core.M3b') }}"><img src="{{ url_for('static', filename='images/ratp/M3b.png') }}"></a>
<a href="{{ url_for('core.M4') }}"><img src="{{ url_for('static', filename='images/ratp/M4.png') }}"></a>
<a href="{{ url_for('core.M5') }}"><img src="{{ url_for('static', filename='images/ratp/M5.png') }}"></a>
<a href="{{ url_for('core.M6') }}"><img src="{{ url_for('static', filename='images/ratp/M6.png') }}"></a>
<a href="{{ url_for('core.M7') }}"><img src="{{ url_for('static', filename='images/ratp/M7.png') }}"></a>
<a href="{{ url_for('core.M7b') }}"><img src="{{ url_for('static', filename='images/ratp/M7b.png') }}"></a>
<a href="{{ url_for('core.M8') }}"><img src="{{ url_for('static', filename='images/ratp/M8.png') }}"></a>
<a href="{{ url_for('core.M9') }}"><img src="{{ url_for('static', filename='images/ratp/M9.png') }}"></a>
<a href="{{ url_for('core.M10') }}"><img src="{{ url_for('static', filename='images/ratp/M10.png') }}"></a>
<a href="{{ url_for('core.M11') }}"><img src="{{ url_for('static', filename='images/ratp/M11.png') }}"></a>
<a href="{{ url_for('core.M12') }}"><img src="{{ url_for('static', filename='images/ratp/M12.png') }}"></a>
<a href="{{ url_for('core.M13') }}"><img src="{{ url_for('static', filename='images/ratp/M13.png') }}"></a>
<a href="{{ url_for('core.M14') }}"><img src="{{ url_for('static', filename='images/ratp/M14.png') }}"></a>




{% endblock %}