{% extends "layout/login.html" %}
{% block body %}

 <div class="login-page">
  <form class="register-form" method=post action=""> 
  <div class="form">  

      <input type="password" id="password" name="password" 
            placeholder="{{_('New password')}}" value="{{ request.form.password }}"
            required>
      <button>{{_("Change password")}}</button>
   
    </form>
  </div>
</div>
{% endblock %}